@@ -1,7 +1,7 @@
 package Org::Document;
 
-our $DATE = '2016-04-01'; # DATE
-our $VERSION = '0.47'; # VERSION
+our $DATE = '2016-07-14'; # DATE
+our $VERSION = '0.48'; # VERSION
 
 use 5.010;
 use locale;
@@ -24,8 +24,8 @@ has radio_targets           => (is => 'rw');
 has time_zone               => (is => 'rw');
 
 our $tags_re       = qr/:(?:[A-Za-z0-9_@#%]+:)+/;
-my  $ls_re         = qr/(?:(?<=[\015\012])|\A)/;
-my  $le_re         = qr/(?:\R|\z)/;
+my  $ls_re         = qr/(?:(?<=[\015\012])|\A)/; # line start
+my  $le_re         = qr/(?:\R|\z)/;              # line end
 our $arg_re        = qr/(?: '(?<squote> [^']*)' |
                             "(?<dquote> [^"]*)" |
                             (?<bare> \S+) )
@@ -79,7 +79,7 @@ my $block_elems_re = # top level elements
                      (?<setting_name> \w+): [ \t]+
                      (?<setting_raw_arg> [^\n]+) $le_re) |
        (?<fixedw>    (?: $ls_re [ \t]* (?::[ ][^\n]* | :$) $le_re )+ ) |
-       (?<comment>   $ls_re \#[^\n]*(?:\R\#[^\n]*)* (?:\R|\z)) |
+       (?<comment>   $ls_re [ \t]*\#[^\n]*(?:\R\#[^\n]*)* (?:\R|\z)) |
        (?<headline>  $ls_re (?<h_bullet>\*+) [ \t]
                      (?<h_title>[^\n]*?)
                      (?:[ \t]+(?<h_tags> $tags_re))?[ \t]* $le_re) |
@@ -377,7 +377,8 @@ sub _parse {
             # recognize todo keyword
             my $todo_kw_re = "(?:".
                 join("|", map {quotemeta}
-                         @{$self->todo_states}, @{$self->done_states}) . ")";
+                     "COMMENT",
+                     @{$self->todo_states}, @{$self->done_states}) . ")";
             if ($title =~ s/^($todo_kw_re)(\s+|\W)/$2/) {
                 my $state = $1;
                 $title =~ s/^\s+//;
@@ -393,9 +394,9 @@ sub _parse {
                 $el->priority($1);
             }
 
-            # recognize progress cookie
+            # recognize statistics cookie
             if ($title =~ s!\[(\d+%|\d+/\d+)\]\s*!!o) {
-                $el->progress($1);
+                $el->statistics_cookie($1);
             }
 
             $el->title($self->_add_text_container($title, $parent, $pass));
@@ -786,7 +787,7 @@ Org::Document - Represent an Org document
 
 =head1 VERSION
 
-This document describes version 0.47 of Org::Document (from Perl distribution Org-Parser), released on 2016-04-01.
+This document describes version 0.48 of Org::Document (from Perl distribution Org-Parser), released on 2016-07-14.
 
 =head1 SYNOPSIS
 
