@@ -1,7 +1,7 @@
 package Org::Dump;
 
-our $DATE = '2016-04-01'; # DATE
-our $VERSION = '0.47'; # VERSION
+our $DATE = '2016-07-14'; # DATE
+our $VERSION = '0.48'; # VERSION
 
 use 5.010;
 use strict;
@@ -46,7 +46,7 @@ sub _dump {
         $line .= " tags=[".join(",", @{$el->tags})."]" if $el->tags;
         $line .= " todo=".$el->todo_state if $el->todo_state;
         $line .= " prio=".$el->priority if $el->priority;
-        $line .= " prog=".$el->progress if $el->progress;
+        $line .= " prog=".$el->statistics_cookie if $el->statistics_cookie;
     } elsif ($type eq 'Footnote') {
         $line .= " name=".($el->name // "");
     } elsif ($type eq 'Block') {
@@ -132,7 +132,7 @@ Org::Dump - Show Org document/element object in a human-friendly format
 
 =head1 VERSION
 
-This document describes version 0.47 of Org::Dump (from Perl distribution Org-Parser), released on 2016-04-01.
+This document describes version 0.48 of Org::Dump (from Perl distribution Org-Parser), released on 2016-07-14.
 
 =head1 FUNCTIONS
 
