@@ -1,7 +1,7 @@
 package Org::Element;
 
-our $DATE = '2016-04-01'; # DATE
-our $VERSION = '0.47'; # VERSION
+our $DATE = '2016-07-14'; # DATE
+our $VERSION = '0.48'; # VERSION
 
 use 5.010;
 use locale;
@@ -72,7 +72,13 @@ sub walk {
     $_level //= 0;
     $code->($self, $_level);
     if ($self->children) {
-        $_->walk($code, $_level+1) for @{$self->children};
+        # we need to copy children first to a temporary array so that in the
+        # event when during walk a child is removed, all the children are still
+        # walked into.
+        my @children = @{ $self->children };
+        for (@children) {
+            $_->walk($code, $_level+1);
+        }
     }
     $_->walk($code, $_level+1) for $self->extra_walkables;
 }
@@ -180,7 +186,7 @@ Org::Element - Base class for Org document elements
 
 =head1 VERSION
 
-This document describes version 0.47 of Org::Element (from Perl distribution Org-Parser), released on 2016-04-01.
+This document describes version 0.48 of Org::Element (from Perl distribution Org-Parser), released on 2016-07-14.
 
 =head1 SYNOPSIS
 
